@@ -1,15 +1,13 @@
-# -*- coding: utf-8 -*-
 """igcommit - Checks on Git commit lists
 
-Copyright (c) 2016, InnoGames GmbH
+Copyright (c) 2021 InnoGames GmbH
+Portions Copyright (c) 2021 Emre Hasegeli
 """
 
-from __future__ import unicode_literals
-
 from time import time
 
 from igcommit.base_check import BaseCheck, Severity
-from igcommit.git import CommitList, Commit
+from igcommit.git import Commit, CommitList
 
 
 class CommitListCheck(BaseCheck):
@@ -133,9 +131,11 @@ class CheckContributors(CommitListCheck):
     def prepare(self, obj):
         new = super(CheckContributors, self).prepare(obj)
         if new and isinstance(obj, CommitList):
-            self.email_index = {}
-            self.domain_index = {}
-            self.name_index = {}
+            new.email_index = {}
+            new.domain_index = {}
+            new.name_index = {}
+
+        return new
 
     def get_problems(self):
         old_contributors = self.get_old_contributors()
